/*
 * Single background pixel model API.
 *
 * This API allows the user to determine, be provided with the RGB values,
 * if the pixel belongs to the background or not.
 *
 * This is only an API proposition and subjected to further changes.
 */

#ifndef _BG_MODEL_H
#define _BG_MODEL_H

enum bg_colorspace {
	BG_COLORSPACE_RGB
};

enum bg_model_type {
	BG_MODEL_MOG	/* Mixture of Gaussians model */
};

struct bg_model;

struct bg_model *bg_model_new(enum bg_model_type model);
void bg_model_init(struct bg_model *bg);
void bg_model_clear(struct bg_model *bg);
void bg_model_free(struct bg_model **bg);

/* Set colorspace. The only colorspace supported is BG_COLORSPACE_RGB. */
void bg_model_set_colorspace(struct bg_model *bg, enum bg_colorspace colorspace);
int bg_model_get_colorspace(struct bg_model *bg);

/* Set underlying model parameters using param string. */
void bg_model_set_parameters(struct bg_model *bg, const char *param);

/* Set depth of the pixel value history cyclic buffer. */
void bg_model_set_history_size(struct bg_model *bg, int size);
int bg_model_get_history_size(struct bg_model *bg);

/* Update the history with a new pixel value. Arguments [x,y,z] stay for
 * [R,G,B] values in BG_COLORSPACE_RGB.
 */
void bg_model_history_add(struct bg_model *bg, int x, int y, int z);

/* Reset the history and forget all previous pixel values. */
void bg_model_history_reset(struct bg_model *bg);

/* Acquire background model for the single pixel using it's collected historical values. */
void bg_model_acquire(struct bg_model *bg);

/* Update background model using a new pixel value. Arguments [x,y,z]
 * stay for [R,G,B] values in BG_COLORSPACE_RGB. */
void bg_model_update(struct bg_model *bg, int x, int y, int z);

/* Reset the model to initial state. This resets underlaying mathematical model
 * to initial state too. */
void bg_model_reset(struct bg_model *bg);

/* Determine, according to current background model, if a pixel [x,y,z]
 * represents background or not. Arguments [x,y,z] stay for [R,G,B] values in
 * BG_COLORSPACE_RGB */
void bg_model_pixel_is_background(struct bg_model *bg, int x, int y, int z);

#endif	/* _BG_MODEL_H */

